==> jc-1.4.0.tar.gz: soot/jimple/JimpleMethodSource.h <==
// public class soot.jimple.JimpleMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 468451bea5a857f5 soot_jimple_JimpleMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_JimpleMethodSource_H_
#define _JC_soot_jimple_JimpleMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_parser_JimpleAST$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleMethodSource$sub_refs	_jc_soot_jimple_JimpleMethodSource$sub_refs;
typedef struct _jc_soot_jimple_JimpleMethodSource$sub_nonrefs	_jc_soot_jimple_JimpleMethodSource$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleMethodSource$refs	_jc_soot_jimple_JimpleMethodSource$refs;
typedef struct _jc_soot_jimple_JimpleMethodSource$nonrefs	_jc_soot_jimple_JimpleMethodSource$nonrefs;
typedef struct _jc_soot_jimple_JimpleMethodSource$object	_jc_soot_jimple_JimpleMethodSource$object;

typedef const struct _jc_soot_jimple_JimpleMethodSource$vmethods	_jc_soot_jimple_JimpleMethodSource$vmethods;
typedef const struct _jc_soot_jimple_JimpleMethodSource$vtable	_jc_soot_jimple_JimpleMethodSource$vtable;
typedef const struct _jc_soot_jimple_JimpleMethodSource$vtype	_jc_soot_jimple_JimpleMethodSource$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleMethodSource$method$_init$5287ff6c861fb27f(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_jimple_parser_JimpleAST$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_jimple_JimpleMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_jimple_JimpleMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_jimple_JimpleMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_JimpleMethodSource$vmethods	soot_jimple_JimpleMethodSource;
};

// Vtype
struct _jc_soot_jimple_JimpleMethodSource$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleMethodSource$sub_refs {
	struct _jc_soot_jimple_parser_JimpleAST$object	*mJimpleAST;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleMethodSource$refs {
    _jc_soot_jimple_JimpleMethodSource$sub_refs	soot_jimple_JimpleMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_JimpleMethodSource$sub_nonrefs	soot_jimple_JimpleMethodSource;
};

// Object instance structure
struct _jc_soot_jimple_JimpleMethodSource$object {
	_jc_soot_jimple_JimpleMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleMethodSource$vtype	*vtype;
	_jc_soot_jimple_JimpleMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleMethodSource$vtype _jc_soot_jimple_JimpleMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleMethodSource$class_object;

#endif	/* _JC_soot_jimple_JimpleMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/JimpleMethodSource.h <==
// public class soot.jimple.JimpleMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 468451bea5a857f5 soot_jimple_JimpleMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_JimpleMethodSource_H_
#define _JC_soot_jimple_JimpleMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_parser_JimpleAST$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleMethodSource$sub_refs	_jc_soot_jimple_JimpleMethodSource$sub_refs;
typedef struct _jc_soot_jimple_JimpleMethodSource$sub_nonrefs	_jc_soot_jimple_JimpleMethodSource$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleMethodSource$refs	_jc_soot_jimple_JimpleMethodSource$refs;
typedef struct _jc_soot_jimple_JimpleMethodSource$nonrefs	_jc_soot_jimple_JimpleMethodSource$nonrefs;
typedef struct _jc_soot_jimple_JimpleMethodSource$object	_jc_soot_jimple_JimpleMethodSource$object;

typedef const struct _jc_soot_jimple_JimpleMethodSource$vmethods	_jc_soot_jimple_JimpleMethodSource$vmethods;
typedef const struct _jc_soot_jimple_JimpleMethodSource$vtable	_jc_soot_jimple_JimpleMethodSource$vtable;
typedef const struct _jc_soot_jimple_JimpleMethodSource$vtype	_jc_soot_jimple_JimpleMethodSource$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleMethodSource$method$_init$5287ff6c861fb27f(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_jimple_parser_JimpleAST$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_jimple_JimpleMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_jimple_JimpleMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_jimple_JimpleMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_JimpleMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_JimpleMethodSource$vmethods	soot_jimple_JimpleMethodSource;
};

// Vtype
struct _jc_soot_jimple_JimpleMethodSource$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleMethodSource$sub_refs {
	struct _jc_soot_jimple_parser_JimpleAST$object	*mJimpleAST;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleMethodSource$refs {
    _jc_soot_jimple_JimpleMethodSource$sub_refs	soot_jimple_JimpleMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_JimpleMethodSource$sub_nonrefs	soot_jimple_JimpleMethodSource;
};

// Object instance structure
struct _jc_soot_jimple_JimpleMethodSource$object {
	_jc_soot_jimple_JimpleMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleMethodSource$vtype	*vtype;
	_jc_soot_jimple_JimpleMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleMethodSource$vtype _jc_soot_jimple_JimpleMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleMethodSource$class_object;

#endif	/* _JC_soot_jimple_JimpleMethodSource_H_ */
